# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2017-02-07 08:34
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ads', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='AdImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('device', models.CharField(choices=[(b'xs', 'Smartphones'), (b'sm', 'Tablets'), (b'md', 'Small Desktops'), (b'lg', 'Large Desktops')], max_length=2, verbose_name='Device')),
                ('image', models.ImageField(max_length=255, upload_to=b'', verbose_name='Image')),
                ('ad', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='images', to='ads.Ad', verbose_name='Ad')),
            ],
        ),
    ]
